@@ -1,6 +1,6 @@
 package Net::Appliance::Session;
 {
-  $Net::Appliance::Session::VERSION = '3.120580_001';
+  $Net::Appliance::Session::VERSION = '3.121990_001';
 }
 
 use Moose;
@@ -107,13 +107,17 @@ sub _build_nci {
     $self->connect_options->{host} = $self->host
         if $self->has_host;
 
-    return Net::CLI::Interact->new({
+    my $nci = Net::CLI::Interact->new({
         transport => $self->transport,
         personality => $self->personality,
         connect_options => $self->connect_options,
         ($self->has_app ? (app => $self->app) : ()),
         ($self->has_add_library ? (add_library => $self->add_library) : ()),
     });
+
+    $nci->logger->log('engine', 'notice',
+        sprintf "NAS loaded, version %s", ($Net::Appliance::Session::VERSION || 'devel'));
+    return $nci;
 }
 
 1;
@@ -130,7 +134,7 @@ Net::Appliance::Session - Run command-line sessions to network appliances
 
 =head1 VERSION
 
-version 3.120580_001
+version 3.121990_001
 
 =head1 IMPORTANT NOTE ABOUT UPGRADING FROM VERSION 2.x
 
@@ -227,7 +231,10 @@ name of the target device in this parameter.
 
 Some of the transport backends can take their own options. For example with a
 serial line connection you might specify the port speed, etc. See the
-respective manual pages for each transport backend for further details.
+respective manual pages for each transport backend for further details
+(L<SSH|Net::CLI::Interact::Transport::SSH>,
+L<Telnet|Net::CLI::Interact::Transport::Telnet>,
+L<Serial|Net::CLI::Interact::Transport::Serial>).
 
 =item C<< add_library => $directory >>
 
@@ -428,7 +435,7 @@ The standard, and recommended way to use this module is as above, whereby the
 application is blocked waiting for command response. It's also possible to
 send a command, and separately return to ask for output at a later time.
 
- $s->put('show clock');
+ $s->say('show clock');
 
 This will send the command C<show clock> to the connected device, followed by
 a newline character.
@@ -437,7 +444,11 @@ a newline character.
 
 This will gather and return output, with similar behaviour to C<cmd()>, above.
 That is, it blocks waiting for output and a prompt, will timeout, and accepts
-the same options. You can still use C<last_response> after calling C<gather>.
+the same options.
+
+You can still use C<last_response> after calling C<gather>, however be aware
+that the command (from C<say>) may be echoed at the start of the output,
+depending on device and connection transport.
 
 =head1 DIAGNOSTICS
 
